@@ -257,7 +257,7 @@ EOM
     # and this storageclass name is not equal to 'cms-data', 
     # which means user has predefined provisioner/CSI ready in the cluster and no need to deploy cms-nfs.
     # Update profile to remove cms-nfs components in this case.
-    if [[ -n ${STORAGECLASS_NAME} ]] && [[ ${STORAGECLASS_NAME} != "cms-data" ]]; then
+    if ([[ -n ${STORAGECLASS_NAME} ]] && [[ ${STORAGECLASS_NAME} != "cms-data" ]]) || [[ ${CLOUDPLATFORM} == "AWS" ]]; then
       echo "[INFO] Updating profile to remove cms-nfs component while using user provided storageclass [$STORAGECLASS_NAME]."
       #yq d -i $PROFILEFOLDER/prof_cms-common_$COMMON_PROFILE_VERSION.yaml 'packages.(deploy-package==cms-nfs)'
       yq -i 'del(.packages.[] | select (.deploy-package == "cms-nfs") )' $PROFILEFOLDER/prof_cms-common_$COMMON_PROFILE_VERSION.yaml
@@ -790,7 +790,83 @@ EOM
       yq -i '.cms_etcd.persistentVolume.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
     fi
 
+    # Modification for deployment on AWS cloud platform
+    if [[ ${CLOUDPLATFORM} == "AWS" ]]; then
+      yq -i '.platformProvider="EKS"' ${PRODUCTSVAR_FILE}
+      yq -i ".awsRegion=\"${AWS_REGION}\"" ${PRODUCTSVAR_FILE}
+
+
+      if [[ -z "$IMAGE_REGISTRY" ]]; then
+        echo "[ERROR] image_registry is empty and required with EKS, make a proper value is provided in cms.var file."
+        exit 1
+      else 
+        echo "[INFO] Update the docker registry with \"${IMAGE_REGISTRY}\"."
+        yq -i ".docker_registry=\"${IMAGE_REGISTRY}\"" ${PRODUCTSVAR_FILE}
+      fi
+     
+      file_storage_class='efs'
+      
+      echo "[INFO] Update CMS PVCs with storageclass [$file_storage_class]."
+      sed -i "s/storageClass: "cms-data"/storageClass: \"$file_storage_class\"/" ${PRODUCTSVAR_FILE}
+
+      echo "[INFO] Update cms-conf PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmsconf.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update cms-plugin PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmsplugin.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update cms-content PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmscontent.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      #echo "[INFO] Update cms-content-heavy PVCs with static share storageclass [$file_storage_class]."
+      #yq w -i ${PRODUCTSVAR_FILE} "cms_pvc.cmscontentheavy.storageClass" "$file_storage_class"
+      echo "[INFO] Update cms-metadata-manager-content PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmsmetadatamanagercontent.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update backup-restore PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.backuprestore.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update cmscli-plugin PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmscliplugin.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update cms-sync-utils PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmssyncutils.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update cms-service-client PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmsserviceclient.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update cms-workflow-runtime PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmsworkflowruntime.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update cms-watchfolder-runtime PVCs with static share storageclass [$file_storage_class]."
+      yq -i ".cms_pvc.cmswatchfolderruntime.storageClass=\"$file_storage_class\"" ${PRODUCTSVAR_FILE}
+
+      echo "[INFO] Update CMS PVCs with storageclass [$file_storage_class]."
+      sed -i "s/storageClass: \"cms-data\"/storageClass: \"$file_storage_class\"/" ${PRODUCTSVAR_FILE}
+
+
+      echo "[INFO] Update ES data PVC with storageclass [cms-disk]."
+      yq -i '.cms_esLogging.persistentVolume.data.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_esLogging.persistentVolume.master.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_esApplication.persistentVolume.data.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_esApplication.persistentVolume.master.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+
+      echo "[INFO] Update RabbitMQ PVC with storageclass [cms-disk]."
+      #sed -i '/^cms_rabbitmq:/{:a;N;/  storageClass:.*/!{$!ba};s/  storageClass:.*/  storageClass: \"cms-disk\"/}' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_rabbitmq.persistentVolume.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+
+      echo "[INFO] Update logstash PVC with storageclass [cms-disk]."
+      #sed -i '/^  cms_logstash:/{:a;N;/  storageClass:.*/!{$!ba};s/  storageClass:.*/  storageClass: \"cms-disk\"/}' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_pvc.cms_logstash.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+
+      echo "[INFO] Update Database PVC with storageclass [cms-disk]."
+      yq -i '.cms_postgresql.persistentVolume.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+
+      echo "[INFO] Update ETCD PVC with storageclass [cms-disk]."
+      yq -i '.cms_etcd.persistentVolume.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
+    fi
+    # Modification for deployment on AWS cloud platform
+
+
+    # Modification for deployment on AWS cloud platform
+    #TODO: remove?
+    if [[ ${CLOUDPLATFORM} == "AWS" ]]; then
+       AWS_EKS_ARN=$(grep OUTPUT_EKS_ARN "${CLOUD_ENV}" | awk -F '=' '{gsub(/"/, "", $2); print $2}')
+    fi
+
     # Modification for cloud deployment cases
+    
     if [[ -n ${CLOUDPLATFORM} ]]; then
       # Update the External static IP (No need to create LoadBalancer in advance)
       external_vip=$(grep OUTPUT_EXTERNAL_VIP ${CLOUD_ENV} | awk -F '=' '{print $2}')
@@ -819,11 +895,12 @@ EOM
 
       outbound_ip=$(grep OUTPUT_OUTBOUND_IP ${CLOUD_ENV} | awk -F '=' '{print $2}')
       if [[ -z "$outbound_ip" ]]; then
-        echo "[ERROR] OUTPUT_OUTBOUND_IP can not be found in file ${CLOUD_ENV}."
-        exit 1
+        echo "[WARNING] OUTPUT_OUTBOUND_IP is empty or not found, skip adding it to lbWhiteList."
+        OUTBOUND_IP_sed="[]"
+      else
+        OUTBOUND_IP_sed="[$(echo $outbound_ip | sed -e 's/"//g')\/32]"
+        echo "[INFO] Cloud platform's OUTBOUND_IP list: $OUTBOUND_IP_sed"
       fi
-      OUTBOUND_IP_sed="[$(grep OUTPUT_OUTBOUND_IP ${CLOUD_ENV} | awk -F '=' '{print $2}'|sed -e 's/"//g')\/32]"
-      echo "[INFO] Cloud platform's OUTBOUND_IP list: $OUTBOUND_IP_sed"
 
       EXT_WHITE_LIST_sed=$(echo $EXT_WHITE_LIST|sed -e 's/\//\\\//g')
       if [[ $BASTION_VM_IP_sed != "[]" ]]; then
@@ -840,10 +917,17 @@ EOM
 
       echo "[INFO] Updating cms_haproxy lbWhiteList ${LB_WHITE_LIST_sed}"
       sed -i '/^cms_haproxy:/{:a;N;/  lbWhiteList:.*/!{$!ba};s/  lbWhiteList:.*/  lbWhiteList: '$LB_WHITE_LIST_sed'/}' ${PRODUCTSVAR_FILE}
+      
+      echo "[INFO] Set cms_haproxy lbWhiteList to ${LB_WHITE_LIST_sed}."
 
-      LB_WHITE_LIST_sed2=$(echo $OUTBOUND_IP_sed|sed -e 's/]/,/g')$(echo $LB_WHITE_LIST_sed|sed -e 's/\[//g')     
-      echo "[INFO] Updating cms_haproxy lbWhiteList ${LB_WHITE_LIST_sed2}"
-      sed -i '/^cms_haproxy:/{:a;N;/  lbWhiteList:.*/!{$!ba};s/  lbWhiteList:.*/  lbWhiteList: '$LB_WHITE_LIST_sed2'/}' ${PRODUCTSVAR_FILE}
+
+      if [[ ${CLOUDPLATFORM} != "AWS" ]]; then
+        LB_WHITE_LIST_sed2=$(echo $OUTBOUND_IP_sed|sed -e 's/]/,/g')$(echo $LB_WHITE_LIST_sed|sed -e 's/\[//g')     
+        echo "[INFO] Updating cms_haproxy lbWhiteList ${LB_WHITE_LIST_sed2}"
+        sed -i '/^cms_haproxy:/{:a;N;/  lbWhiteList:.*/!{$!ba};s/  lbWhiteList:.*/  lbWhiteList: '$LB_WHITE_LIST_sed2'/}' ${PRODUCTSVAR_FILE}
+
+        echo "[INFO] Added outbound IP to cms_haproxy lbWhiteList :${LB_WHITE_LIST_sed2}."
+      fi
 
       # Update database storageclass and PV size
       # Common setting for both AKS and GKE
